<?PHP
/**
 * Constains lists for grouping measurement types.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Constains lists for grouping measurement types.
 */
final class MDConcMeasurementTypes implements MDImporterConcordanceListInterface {
    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return MDMeasurementType|false
     */
    public static function getConcordanceTarget(string $input):MDMeasurementType|false {

        return match($input) {

            // Just list entries
            "Allgemein",
            "Passepartout",
            "Passepartout Standardformat",
            "Objektmaß",
            "Objektmass",
            "Außenmaß",
            "Außenmaß (Kiste)",
            "Bildmaß",
            "Bildmass",
            "Bildmaß (HxB)",
            "Auflagekarton (Höhe x Breite)",
            "Passepartout Standardformat (Höhe x Breite)",
            "Blattmaß",
            "Blattmass",
            "m",
            "cm",
            "mm",
            "dm",
            "Spieldauer (h___m___s)",
            "Geschwindigkeit (Schallplatte)",
            "Geschwindigkeit (Band)",
            "Transportmaß (Breite x Höhe x Tiefe)",
            "Transportmaß (Breite x Höhe x Tiefe)Transportmaß (Breite x Höhe x Tiefe)",
            "Öffnung (Durchmesser)",
            "Kartonformat (Höhe x Breite)",
            "Negativformat (Breite x Lange)",
            "Passepartout (Höhe x Breite)",
            "Montage (Breite x Länge)",
            "Verpackungsmaß (Breite x Höhe x Tiefe)Verpackungsmaß (Breite x Höhe x Tiefe)",
            "Maße Transport (Höhe x Tiefe x Breite)",
            "Volumen",
            "Hohlmaß",
            "Buchformat",
            "Hohlmass",
            "Kaliber",
            "Zeit",
            "Maßstab",
            "Original",
            "size",
            "base",
            "target",
            "Modell",
            "",
            "Plattengröße (Höhe x Breite)",
            "Sockel (Höhe x Tiefe x Breite)",
            "Sockel (Höhe x Tiefe x                                    Breite)",
            "Außenmaß (Höhe x Tiefe x Breite)",
            "Fläche",
            "Tafelmaß",
            "Tafelmass",
            "Radius",
            "Bemalte Fläche",
            "Bemalte Bildfläche",
            "Sockel",
            "Höhe x                                    Breite",
            "Höhe x                                    Durchmesser",
            "Rahmenmaß (Höhe x
                                    Breite)",
            "Höhe x Breite x                                    Tiefe",
            "Höhe x Breite x Tiefe",
            "Rahmenmaß",
            "Rahmenmaß (Höhe x Breite)",
            "Rahmenmaß (Höhe x                                    Breite)",
            "Rahmenmass",
            "Rahmenmass (Höhe x Breite)",
            "Rahmenaußenmaß (Höhe x Breite)",
            "Rahmenaußenmaß (Länge x Durchmesser)",
            "Höhe x Breite x Stärke",
            "Rahmenaußenmaß",
            "Rahmenaußenmass",
            "Kartonformat",
            "Kartonformat (Foto)",
            "Auflagekarton",
            "Bildformat (Foto)",
            "Tafelmaß (Höhe x Breite)",
            "Bemalte Bildfläche (Höhe x Breite)",
            "Plattengröße (Foto)",
            "Andere Maße",
            "Format",
            "Stichhöhe",
            "Maße Transport",
            "Länge x Breite x Höhe",
            "Länge x Breite x                                    Tiefe",
            "Länge x                                    Breite",
            "Maße Transport (Höhe x Tiefe x                                    Breite)",
            "Blattmaß (Höhe x Breite)",
            "Objektmaß (Höhe x Tiefe x Breite)",
            "Objektmaß (Höhe x Tiefe x                                    Breite)",
            "Teil 1",
            "Teil 2",
            "Teil 3",
            "Teil 4",
            "Teil 5",
            "Teil 6",
            "Teil 7",
            "Teil 8",
            "Kistenmaß (Länge x Breite x Höhe)",
            "Umfang",
            "Umfang",
            "Kaliber",
            "Ölfarbe",
            "2 kg-Gewicht",
            "2. Hälfte 18. Jh.",
            "14.1x9.2",
            "14x9.1",
            "cm",
            "13.9x8.6",
            "Grundfläche",
            "Länge x Breite",
            "Bildmaß (Höhe x Breite)",
            "Bildformat (Höhe x Breite)",
            "Glasmaß (Höhe x Breite)",
            "Länge x Breite x Tiefe",
            "Höhe x Durchmesser",
            "Länge x Durchmesser",
            "Breite x Höhe",
            "Breite x Höhe x Tiefe",
            "Breite x                                    Höhe",
            "Breite x Tiefe",
            "Höhe x Breite",
            "Höhe x Breite (aufgeschlagen)",
            "Höhe x Breite x Tiefe",
            "Durchmesser x Tiefe",
            "Durchmesser x                                    Tiefe",
            "Gesamtmaß (Höhe x Breite x Tiefe)",
            "Form",
            "Andere",
            "Prefix",
            "Kartierung",
            "Masstab",
            "Sitzhöhe",
            "Auflagekarton Standardformat",
            "Bruttomass",
            "Kistenmass",
            "Kistenmass (Höhe)",
            "Lichtmass",
            "Kistenmass (Tiefe)",
            "Kistenmass (Breite)",
            "Suffix",
            "HxBxT",
            "Objektmaß (HxB)",
            "CC",
            "Eisen",
            "mm",
            "Größe",
            "CdV",
            "Stichhöhe (Höhe x Breite)" => false,

            "Höhe",
            "(Höhe)",
            " (Höhe)",
            "Höhe (gesamt)",
            "Höhe (Etui)",
            "Höhe (netto)",
            "Höhe (ausgeklappt)",
            "Höhe größtes Stück",
            "height",
            "height (overall)",
            "Lichtmass (Höhe)",
            "Bruttomass (Höhe)",
            "Kartierung (Höhe)",
            "Masstab (Höhe)",
            "Sitzhöhe (Höhe)",
            "Außenmaß (Höhe)",
            "Objektmaß (Höhe)",
            "Objektmass (Höhe)",
            "Reliefhöhe" => MDMeasurementType::height,

            "Länge",
            "Länge OT",
            "Länge H",
            "Länge (ausgeklappt)",
            "length",
            "(Länge)",
            " (Länge)",
            "Lichtmass (Länge)",
            "Lichtmass (Tiefe)",
            "Tiefe",
            "Tiefe (mit Hinterrad in Fahrtrichtung)",
            "Tiefe (zusammengeklappt)",
            "Tiefe (Etui)",
            "Tiefe (mit eingeklapptem Hinterrad)",
            "Tiefe/Länge",
            "Tiefe min",
            "Tiefe max",
            "Außenmaß (Tiefe)",
            "Teife",
            "length",
            "Bruttomass (Länge)",
            "Bruttomass (Tiefe)",
            "Kartierung (Länge)",
            "Kartierung (Tiefe)",
            "Masstab (Länge)",
            "Masstab (Tiefe)",
            "Sitzhöhe (Länge)",
            "Sitzhöhe (Tiefe)",
            "Objektmaß (Länge)",
            "Objektmaß (Tiefe)",
            "Objektmass (Länge)",
            "Objektmass (Tiefe)",
            "depth",
            "Dicke" => MDMeasurementType::length,

            "Breite",
            "Breite OT",
            "Breite H",
            "Breite (ausgeklappt)",
            "Breite (Etui)",
            "Breite (netto)",
            "Breite (aufgeschlagen)",
            "Breite größtes Stück",
            "Breite (gesamt)",
            "(Breite)",
            "Lichtmass (Breite)",
            " (Breite)",
            "width",
            "width (overall)",
            "Außenmaß (Breite)",
            "Bruttomass (Breite)",
            "Objektmaß (Breite)",
            "Objektmass (Breite)",
            "Kartierung (Breite)",
            "Masstab (Breite)",
            "Sitzhöhe (Breite)",
            "Stärke",
            "Schenkelbreite (Breite)" => MDMeasurementType::width,

            "Durchmesser",
            "Durchm.",
            "Durchmesser (mit Dicke)",
            "Durchmesser (Boden)",
            "Mündung (Durchmesser)",
            "Rahmenaußenmaß Durchmesser",
            "diameter",
            "Außenmaß (Durchmesser)",
            "Durchmesser in Richtung Bohrung",
            "Durchmesser quer zur Bohrung",
            "Durchmesser Fuß",
            "Durchmesser Oben",
            "Durchmesser oben",
            "Durchmesser unten",
            "Durchmesser (Höhe)",
            "Durchmesser (Breite)",
            "Durchmesser (Tiefe)",
            "Durchmesser (Länge)",
            "Objektmaß (Durchmesser)",
            "Objektmass (Durchmesser)",
            "d",
            "Ø" => MDMeasurementType::diameter,

            "width of wall",
            "Laufwandung",
            "Stärke",
            "Wandstärke (Durchmesser)" => MDMeasurementType::wall,

            "Höhe (Blatt)",
            "Blattmaß (Höhe)",
            "Blattmass (Höhe)" => MDMeasurementType::height_sheet_size,

            "Breite (Blatt)",
            "Blattmaß (Breite)",
            "Blattmass (Breite)" => MDMeasurementType::width_sheet_size,

            "Blattmaß (Länge)",
            "Blattmaß (Tiefe)",
            "Blattmass (Länge)",
            "Blattmass (Tiefe)" => MDMeasurementType::length_sheet_size,

            "Höhe (Bild)",
            "Bildmaß (Höhe)",
            "Bildmass (Höhe)" => MDMeasurementType::height_image_size,

            "Breite (Bild)",
            "Bildmaß (Breite)",
            "Bildmass (Breite)" => MDMeasurementType::width_image_size,

            "Bildmaß (Länge)",
            "Bildmaß (Tiefe)",
            "Bildmass (Länge)",
            "Bildmass (Tiefe)" => MDMeasurementType::length_image_size,

            "Höhe (Rahmen)",
            "Rahmenmaß (Höhe)",
            "Rahmenmass (Höhe)" => MDMeasurementType::height_frame,

            "Breite (Rahmen)",
            "Rahmenmaß (Breite)",
            "Rahmenmass (Breite)" => MDMeasurementType::width_frame,

            "Tiefe (Rahmen)",
            "Rahmenmaß (Länge)",
            "Rahmenmaß (Tiefe)",
            "Rahmenmass (Länge)",
            "Rahmenmass (Tiefe)" => MDMeasurementType::length_frame,

            "Höhe min." => MDMeasurementType::height_min,
            "Höhe max." => MDMeasurementType::height_max,

            "Länge min.",
            "Tiefe min." => MDMeasurementType::length_min,
            "Länge max.",
            "Tiefe max." => MDMeasurementType::length_max,

            "Breite min." => MDMeasurementType::width_min,
            "Breite max." => MDMeasurementType::width_max,

            "Diameter min." => MDMeasurementType::diameter_min,
            "Diameter max." => MDMeasurementType::diameter_max,

            "Durchmesser (Rahmen)" => MDMeasurementType::diameter_frame,

            "weight",
            "Gewicht (Höhe)",
            "Gewicht (Breite)",
            "Gewicht (Tiefe)",
            "Gewicht (Länge)",
            "Gewicht" => MDMeasurementType::weight,

            "number of pages",
            "Seitenzahl",
            "Seitenzahl (Höhe)",
            "Seitenzahl (Breite)",
            "Seitenzahl (Tiefe)",
            "Paginierung" => MDMeasurementType::number_of_parts,

            "Die Axis",
            "die-axis",
            "orientation",
            "Stempelstellung" => MDMeasurementType::die_axis,

            default => throw new MDImporterMissingConcordance("Unmapped specific measurement type: " . $input),

        };

    }
}
